==> mysql-community_8.3.0.orig.tar.gz: mysql-8.3.0/storage/ndb/include/kernel/signaldata/InvalidateNodeLCPConf.hpp <==
/*
   Copyright (c) 2003, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef INVALIDATE_NODE_LCP_CONF_HPP
#define INVALIDATE_NODE_LCP_CONF_HPP

#define JAM_FILE_ID 159

/**
 * This signal is sent from the non-master DIH to master DIHs
 *
 */
class InvalidateNodeLCPConf {
  /**
   * Sender/Receiver
   */
  friend class Dbdih;

  /**
   * NodeId of sending node
   * which is "done"
   */
  Uint32 sendingNodeId;

 public:
  static constexpr Uint32 SignalLength = 1;
};

#undef JAM_FILE_ID

#endif

==> mysql-community_8.4.3.orig.tar.gz: mysql-8.4.3/storage/ndb/include/kernel/signaldata/InvalidateNodeLCPConf.hpp <==
/*
   Copyright (c) 2003, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef INVALIDATE_NODE_LCP_CONF_HPP
#define INVALIDATE_NODE_LCP_CONF_HPP

#define JAM_FILE_ID 159

/**
 * This signal is sent from the non-master DIH to master DIHs
 *
 */
class InvalidateNodeLCPConf {
  /**
   * Sender/Receiver
   */
  friend class Dbdih;

  /**
   * NodeId of sending node
   * which is "done"
   */
  Uint32 sendingNodeId;

 public:
  static constexpr Uint32 SignalLength = 1;
};

#undef JAM_FILE_ID

#endif
